
package Google::Ads::AdWords::v201406::TypeMaps::BiddingStrategyService;
use strict;
use warnings;

our $typemap_1 = {
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/reason' => 'Google::Ads::AdWords::v201406::EntityNotFound::Reason',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/biddingScheme[BudgetOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201406::BudgetOptimizerBiddingScheme',
               'queryResponse/rval/entries/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/biddingScheme[TargetRoasBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/biddingScheme[ManualCpmBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201406::Money',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/biddingScheme[ManualCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/biddingScheme[TargetSpendBiddingScheme]/spendTarget/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/biddingScheme/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DateError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/reason' => 'Google::Ads::AdWords::v201406::AuthenticationError::Reason',
               'getResponse/rval/entries/biddingScheme[PageOnePromotedBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/biddingScheme[ConversionOptimizerBiddingScheme]/bidType' => 'Google::Ads::AdWords::v201406::ConversionOptimizerBiddingScheme::BidType',
               'getResponse/rval/entries/biddingScheme' => 'Google::Ads::AdWords::v201406::BiddingScheme',
               'getResponse/rval/entries/biddingScheme[TargetRoasBiddingScheme]/bidFloor' => 'Google::Ads::AdWords::v201406::Money',
               'mutateResponse/rval/value/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BiddingErrors]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/status' => 'Google::Ads::AdWords::v201406::SharedBiddingStrategy::BiddingStrategyStatus',
               'Fault/detail/ApiExceptionFault/errors[DateError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/biddingScheme[TargetRoasBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201406::Money',
               'Fault/detail/ApiExceptionFault/errors[BiddingStrategyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/biddingScheme[TargetRoasBiddingScheme]/bidFloor/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/rateScope' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/biddingScheme[TargetRoasBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidCeiling' => 'Google::Ads::AdWords::v201406::Money',
               'mutate/operations/operand/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidFloor' => 'Google::Ads::AdWords::v201406::Money',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/reason' => 'Google::Ads::AdWords::v201406::NotEmptyError::Reason',
               'mutateResponse/rval/value/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenBudgetConstained' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/reason' => 'Google::Ads::AdWords::v201406::StringLengthError::Reason',
               'Fault/detail/ApiExceptionFault/errors[BiddingErrors]/reason' => 'Google::Ads::AdWords::v201406::BiddingErrors::Reason',
               'get/selector/predicates/field' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BiddingStrategyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/biddingScheme' => 'Google::Ads::AdWords::v201406::BiddingScheme',
               'mutateResponse' => 'Google::Ads::AdWords::v201406::BiddingStrategyService::mutateResponse',
               'Fault/detail/ApiExceptionFault/errors[AdxError]' => 'Google::Ads::AdWords::v201406::AdxError',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/reason' => 'Google::Ads::AdWords::v201406::RateExceededError::Reason',
               'queryResponse/rval/entries/biddingScheme[BudgetOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201406::BudgetOptimizerBiddingScheme',
               'mutateResponse/rval/value/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[BiddingErrors]' => 'Google::Ads::AdWords::v201406::BiddingErrors',
               'get/selector/predicates' => 'Google::Ads::AdWords::v201406::Predicate',
               'queryResponse/rval/entries/biddingScheme[TargetSpendBiddingScheme]' => 'Google::Ads::AdWords::v201406::TargetSpendBiddingScheme',
               'queryResponse/rval/entries/biddingScheme[PageOnePromotedBiddingScheme]' => 'Google::Ads::AdWords::v201406::PageOnePromotedBiddingScheme',
               'mutate/operations/operand/biddingScheme[TargetRoasBiddingScheme]/bidFloor/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/biddingScheme[BudgetOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/biddingScheme[TargetSpendBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/biddingScheme[PageOnePromotedBiddingScheme]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'Fault/detail/ApiExceptionFault/errors[IdError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/reason' => 'Google::Ads::AdWords::v201406::AuthorizationError::Reason',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]' => 'Google::Ads::AdWords::v201406::NewEntityCreationError',
               'Fault/detail/ApiExceptionFault/errors[IdError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/biddingScheme[TargetCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/biddingScheme[ManualCpcBiddingScheme]' => 'Google::Ads::AdWords::v201406::ManualCpcBiddingScheme',
               'getResponse/rval/entries' => 'Google::Ads::AdWords::v201406::SharedBiddingStrategy',
               'mutateResponse/rval/value/status' => 'Google::Ads::AdWords::v201406::SharedBiddingStrategy::BiddingStrategyStatus',
               'mutate/operations/operand/biddingScheme[PageOnePromotedBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/biddingScheme[TargetSpendBiddingScheme]' => 'Google::Ads::AdWords::v201406::TargetSpendBiddingScheme',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BiddingErrors]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/accountLimitType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/biddingScheme[TargetCpaBiddingScheme]/targetCpa/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/biddingScheme[TargetSpendBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201406::Money',
               'queryResponse/rval/entries/biddingScheme[BudgetOptimizerBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/reason' => 'Google::Ads::AdWords::v201406::EntityCountLimitExceeded::Reason',
               'get/selector/paging/numberResults' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/type' => 'Google::Ads::AdWords::v201406::BiddingStrategyType',
               'queryResponse/rval/entries/biddingScheme[TargetRoasBiddingScheme]/bidFloor' => 'Google::Ads::AdWords::v201406::Money',
               'queryResponse/rval/entries/biddingScheme[ManualCpcBiddingScheme]' => 'Google::Ads::AdWords::v201406::ManualCpcBiddingScheme',
               'mutate/operations/operand/biddingScheme[TargetSpendBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/fields' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/biddingScheme[TargetSpendBiddingScheme]/spendTarget' => 'Google::Ads::AdWords::v201406::Money',
               'Fault/detail/ApiExceptionFault/errors[NullError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NullError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/type' => 'Google::Ads::AdWords::v201406::BiddingStrategyType',
               'getResponse/rval/entries/biddingScheme[TargetSpendBiddingScheme]/spendTarget/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get' => 'Google::Ads::AdWords::v201406::BiddingStrategyService::get',
               'Fault' => 'SOAP::WSDL::SOAP::Typelib::Fault11',
               'getResponse/rval/entries/biddingScheme[PageOnePromotedBiddingScheme]/bidChangesForRaisesOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value/biddingScheme[BudgetOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[BiddingStrategyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/biddingScheme[TargetSpendBiddingScheme]/spendTarget/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[DateError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/biddingScheme[TargetSpendBiddingScheme]/spendTarget/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/biddingScheme[TargetCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/type' => 'Google::Ads::AdWords::v201406::BiddingStrategyType',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]' => 'Google::Ads::AdWords::v201406::OperationAccessDenied',
               'mutateResponse/rval/value/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidCeiling' => 'Google::Ads::AdWords::v201406::Money',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]' => 'Google::Ads::AdWords::v201406::QuotaCheckError',
               'mutateResponse/rval/value/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/biddingScheme[BudgetOptimizerBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/biddingScheme[ConversionOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201406::ConversionOptimizerBiddingScheme',
               'mutate/operations/operand/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/biddingScheme[EnhancedCpcBiddingScheme]' => 'Google::Ads::AdWords::v201406::EnhancedCpcBiddingScheme',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QueryError]' => 'Google::Ads::AdWords::v201406::QueryError',
               'Fault/detail/ApiExceptionFault/errors[DateError]/reason' => 'Google::Ads::AdWords::v201406::DateError::Reason',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]' => 'Google::Ads::AdWords::v201406::RateExceededError',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/dateRange/max' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/type' => 'Google::Ads::AdWords::v201406::BiddingStrategyType',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/biddingScheme[TargetRoasBiddingScheme]/bidFloor' => 'Google::Ads::AdWords::v201406::Money',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/biddingScheme[TargetRoasBiddingScheme]/bidFloor/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/biddingScheme[ManualCpcBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries/biddingScheme[PageOnePromotedBiddingScheme]/strategyGoal' => 'Google::Ads::AdWords::v201406::PageOnePromotedBiddingScheme::StrategyGoal',
               'ApiExceptionFault/errors/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/biddingScheme[TargetRoasBiddingScheme]' => 'Google::Ads::AdWords::v201406::TargetRoasBiddingScheme',
               'mutate/operations/operand/biddingScheme[TargetRoasBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/biddingScheme[ConversionOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/biddingScheme[ConversionOptimizerBiddingScheme]/pricingMode' => 'Google::Ads::AdWords::v201406::ConversionOptimizerBiddingScheme::PricingMode',
               'getResponse/rval/entries/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidFloor/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/biddingScheme[PageOnePromotedBiddingScheme]/bidChangesForRaisesOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value/biddingScheme[TargetCpaBiddingScheme]/targetCpa/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/biddingScheme[ConversionOptimizerBiddingScheme]/pricingMode' => 'Google::Ads::AdWords::v201406::ConversionOptimizerBiddingScheme::PricingMode',
               'mutateResponse/rval/value/biddingScheme[TargetRoasBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidFloor' => 'Google::Ads::AdWords::v201406::Money',
               'get/selector/paging/startIndex' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'get/selector/ordering/field' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidFloor/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/biddingScheme[TargetRoasBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]' => 'Google::Ads::AdWords::v201406::StringLengthError',
               'mutate/operations/operand/biddingScheme[PageOnePromotedBiddingScheme]/strategyGoal' => 'Google::Ads::AdWords::v201406::PageOnePromotedBiddingScheme::StrategyGoal',
               'mutate/operations/operand/biddingScheme[ConversionOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201406::ConversionOptimizerBiddingScheme',
               'Fault/faultstring' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/biddingScheme[TargetSpendBiddingScheme]/spendTarget' => 'Google::Ads::AdWords::v201406::Money',
               'queryResponse/rval/totalNumEntries' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries/biddingScheme[PageOnePromotedBiddingScheme]/strategyGoal' => 'Google::Ads::AdWords::v201406::PageOnePromotedBiddingScheme::StrategyGoal',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]' => 'Google::Ads::AdWords::v201406::EntityNotFound',
               'mutate/operations/operand/biddingScheme[PageOnePromotedBiddingScheme]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'queryResponse/rval/entries/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidFloor/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/biddingScheme[TargetRoasBiddingScheme]/bidFloor/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/biddingScheme[ManualCpmBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/reason' => 'Google::Ads::AdWords::v201406::QueryError::Reason',
               'getResponse/rval/entries/biddingScheme[TargetRoasBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/biddingScheme[PercentCpaBiddingScheme]' => 'Google::Ads::AdWords::v201406::PercentCpaBiddingScheme',
               'getResponse/rval/entries/biddingScheme[PercentCpaBiddingScheme]' => 'Google::Ads::AdWords::v201406::PercentCpaBiddingScheme',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]' => 'Google::Ads::AdWords::v201406::EntityCountLimitExceeded',
               'mutate/operations/operand/biddingScheme[TargetCpaBiddingScheme]/targetCpa/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/biddingScheme[PageOnePromotedBiddingScheme]' => 'Google::Ads::AdWords::v201406::PageOnePromotedBiddingScheme',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/reason' => 'Google::Ads::AdWords::v201406::QuotaCheckError::Reason',
               'getResponse/rval/entries/status' => 'Google::Ads::AdWords::v201406::SharedBiddingStrategy::BiddingStrategyStatus',
               'mutateResponse/rval/value/biddingScheme[TargetRoasBiddingScheme]/targetRoas' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/reason' => 'Google::Ads::AdWords::v201406::DatabaseError::Reason',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/reason' => 'Google::Ads::AdWords::v201406::DistinctError::Reason',
               'getResponse/rval/entries/biddingScheme[ManualCpmBiddingScheme]' => 'Google::Ads::AdWords::v201406::ManualCpmBiddingScheme',
               'queryResponse/rval/entries/biddingScheme[TargetCpaBiddingScheme]/targetCpa' => 'Google::Ads::AdWords::v201406::Money',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/biddingScheme[TargetRoasBiddingScheme]/bidFloor/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/biddingScheme[TargetSpendBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201406::Money',
               'Fault/detail/ApiExceptionFault/errors[DateError]' => 'Google::Ads::AdWords::v201406::DateError',
               'getResponse/rval/entries/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/reason' => 'Google::Ads::AdWords::v201406::ClientTermsError::Reason',
               'get/selector/ordering/sortOrder' => 'Google::Ads::AdWords::v201406::SortOrder',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]' => 'Google::Ads::AdWords::v201406::InternalApiError',
               'queryResponse/rval/entries/biddingScheme[TargetCpaBiddingScheme]' => 'Google::Ads::AdWords::v201406::TargetCpaBiddingScheme',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/biddingScheme[BudgetOptimizerBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/biddingScheme[ManualCpmBiddingScheme]' => 'Google::Ads::AdWords::v201406::ManualCpmBiddingScheme',
               'getResponse/rval/entries/biddingScheme[ConversionOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201406::ConversionOptimizerBiddingScheme',
               'mutateResponse/rval/value/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/Page.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/biddingScheme[ConversionOptimizerBiddingScheme]/pricingMode' => 'Google::Ads::AdWords::v201406::ConversionOptimizerBiddingScheme::PricingMode',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/predicates/operator' => 'Google::Ads::AdWords::v201406::Predicate::Operator',
               'queryResponse/rval/entries/biddingScheme[TargetRoasBiddingScheme]/bidFloor/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201406::Money',
               'Fault/detail/ApiExceptionFault/errors[BiddingStrategyError]/reason' => 'Google::Ads::AdWords::v201406::BiddingStrategyError::Reason',
               'mutateResponse/rval/value/biddingScheme[TargetCpaBiddingScheme]/targetCpa/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/biddingScheme[BudgetOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201406::BudgetOptimizerBiddingScheme',
               'Fault/detail/ApiExceptionFault/errors[NullError]' => 'Google::Ads::AdWords::v201406::NullError',
               'getResponse/rval/entries/biddingScheme[TargetCpaBiddingScheme]/targetCpa/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/predicates/values' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201406::Money',
               'getResponse/rval/entries/biddingScheme[PageOnePromotedBiddingScheme]' => 'Google::Ads::AdWords::v201406::PageOnePromotedBiddingScheme',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/biddingScheme[TargetRoasBiddingScheme]' => 'Google::Ads::AdWords::v201406::TargetRoasBiddingScheme',
               'queryResponse/rval/entries/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201406::Money',
               'mutate/operations/operand/biddingScheme[ConversionOptimizerBiddingScheme]/bidType' => 'Google::Ads::AdWords::v201406::ConversionOptimizerBiddingScheme::BidType',
               'getResponse/rval/entries/biddingScheme[TargetCpaBiddingScheme]' => 'Google::Ads::AdWords::v201406::TargetCpaBiddingScheme',
               'getResponse' => 'Google::Ads::AdWords::v201406::BiddingStrategyService::getResponse',
               'Fault/detail/ApiExceptionFault/errors[IdError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/biddingScheme[ConversionOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenLowQualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'queryResponse/rval/entries/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidFloor' => 'Google::Ads::AdWords::v201406::Money',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval' => 'Google::Ads::AdWords::v201406::BiddingStrategyPage',
               'queryResponse/rval' => 'Google::Ads::AdWords::v201406::BiddingStrategyPage',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]' => 'Google::Ads::AdWords::v201406::ClientTermsError',
               'queryResponse/rval/entries/biddingScheme[TargetSpendBiddingScheme]/spendTarget/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/biddingScheme/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/biddingScheme[EnhancedCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/biddingScheme[TargetCpaBiddingScheme]' => 'Google::Ads::AdWords::v201406::TargetCpaBiddingScheme',
               'getResponse/rval/entries/biddingScheme[ManualCpmBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/biddingScheme[PageOnePromotedBiddingScheme]/strategyGoal' => 'Google::Ads::AdWords::v201406::PageOnePromotedBiddingScheme::StrategyGoal',
               'mutateResponse/rval/value/biddingScheme[PageOnePromotedBiddingScheme]/bidChangesForRaisesOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BiddingStrategyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries' => 'Google::Ads::AdWords::v201406::SharedBiddingStrategy',
               'mutate/operations/operand/biddingScheme' => 'Google::Ads::AdWords::v201406::BiddingScheme',
               'mutateResponse/rval/value/biddingScheme[TargetRoasBiddingScheme]/bidFloor' => 'Google::Ads::AdWords::v201406::Money',
               'mutateResponse/rval/value/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenLowQualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/reason' => 'Google::Ads::AdWords::v201406::InternalApiError::Reason',
               'get/selector/dateRange/min' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/biddingScheme[ConversionOptimizerBiddingScheme]/pricingMode' => 'Google::Ads::AdWords::v201406::ConversionOptimizerBiddingScheme::PricingMode',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/reason' => 'Google::Ads::AdWords::v201406::RejectedError::Reason',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/biddingScheme[TargetSpendBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/biddingScheme[TargetRoasBiddingScheme]/bidFloor/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/ApplicationException.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/biddingScheme[ConversionOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201406::ConversionOptimizerBiddingScheme',
               'mutate/operations/operand/biddingScheme[TargetRoasBiddingScheme]/targetRoas' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'Fault/detail/ApiExceptionFault/errors[BiddingErrors]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidFloor' => 'Google::Ads::AdWords::v201406::Money',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RangeError]' => 'Google::Ads::AdWords::v201406::RangeError',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/retryAfterSeconds' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/biddingScheme[BudgetOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/biddingScheme[ManualCpmBiddingScheme]' => 'Google::Ads::AdWords::v201406::ManualCpmBiddingScheme',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/reason' => 'Google::Ads::AdWords::v201406::SelectorError::Reason',
               'mutateResponse/rval/value/biddingScheme[PercentCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BiddingStrategyError]' => 'Google::Ads::AdWords::v201406::BiddingStrategyError',
               'queryResponse/rval/entries/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidFloor/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/biddingScheme[PercentCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]' => 'Google::Ads::AdWords::v201406::DatabaseError',
               'getResponse/rval/entries/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201406::Money',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]' => 'Google::Ads::AdWords::v201406::AuthorizationError',
               'mutateResponse/rval/value/biddingScheme[TargetSpendBiddingScheme]' => 'Google::Ads::AdWords::v201406::TargetSpendBiddingScheme',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/biddingScheme[EnhancedCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/reason' => 'Google::Ads::AdWords::v201406::RequiredError::Reason',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NullError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/ApplicationException.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/paging' => 'Google::Ads::AdWords::v201406::Paging',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[IdError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/biddingScheme[EnhancedCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/reason' => 'Google::Ads::AdWords::v201406::AdxError::Reason',
               'queryResponse/rval/entries/biddingScheme[PageOnePromotedBiddingScheme]/bidChangesForRaisesOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/biddingScheme[TargetRoasBiddingScheme]/targetRoas' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value/biddingScheme[EnhancedCpcBiddingScheme]' => 'Google::Ads::AdWords::v201406::EnhancedCpcBiddingScheme',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operator' => 'Google::Ads::AdWords::v201406::Operator',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/reason' => 'Google::Ads::AdWords::v201406::ReadOnlyError::Reason',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BiddingErrors]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/biddingScheme[TargetCpaBiddingScheme]/targetCpa/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[NullError]/reason' => 'Google::Ads::AdWords::v201406::NullError::Reason',
               'getResponse/rval/entries/biddingScheme[PageOnePromotedBiddingScheme]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201406::Money',
               'mutateResponse/rval/value/biddingScheme[TargetSpendBiddingScheme]/spendTarget/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[IdError]/reason' => 'Google::Ads::AdWords::v201406::IdError::Reason',
               'mutate/operations/operand/biddingScheme[EnhancedCpcBiddingScheme]' => 'Google::Ads::AdWords::v201406::EnhancedCpcBiddingScheme',
               'getResponse/rval/entries/biddingScheme[TargetRoasBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201406::Money',
               'ApiExceptionFault/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/biddingScheme[TargetRoasBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/biddingScheme[PercentCpaBiddingScheme]' => 'Google::Ads::AdWords::v201406::PercentCpaBiddingScheme',
               'Fault/faultactor' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'queryResponse/rval/entries/biddingScheme[PageOnePromotedBiddingScheme]/bidModifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'query' => 'Google::Ads::AdWords::v201406::BiddingStrategyService::query',
               'ApiExceptionFault/errors' => 'Google::Ads::AdWords::v201406::ApiError',
               'queryResponse/rval/entries/biddingScheme[ConversionOptimizerBiddingScheme]/bidType' => 'Google::Ads::AdWords::v201406::ConversionOptimizerBiddingScheme::BidType',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/biddingScheme[EnhancedCpcBiddingScheme]' => 'Google::Ads::AdWords::v201406::EnhancedCpcBiddingScheme',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]' => 'Google::Ads::AdWords::v201406::SizeLimitError',
               'queryResponse/rval/entries/biddingScheme[TargetSpendBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201406::Money',
               'mutateResponse/rval/value/biddingScheme[ConversionOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/biddingScheme[ManualCpcBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/biddingScheme[TargetRoasBiddingScheme]' => 'Google::Ads::AdWords::v201406::TargetRoasBiddingScheme',
               'mutateResponse/rval/value/biddingScheme[TargetCpaBiddingScheme]/targetCpa' => 'Google::Ads::AdWords::v201406::Money',
               'mutate/operations/operand/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate' => 'Google::Ads::AdWords::v201406::BiddingStrategyService::mutate',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/faultcode' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/biddingScheme[ConversionOptimizerBiddingScheme]/bidType' => 'Google::Ads::AdWords::v201406::ConversionOptimizerBiddingScheme::BidType',
               'getResponse/rval/entries/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors' => 'Google::Ads::AdWords::v201406::ApiError',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse' => 'Google::Ads::AdWords::v201406::BiddingStrategyService::queryResponse',
               'getResponse/rval/entries/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenBudgetConstained' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NullError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidFloor/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/biddingScheme/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/biddingScheme[TargetSpendBiddingScheme]/spendTarget/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/ordering' => 'Google::Ads::AdWords::v201406::OrderBy',
               'mutate/operations/operand/biddingScheme[TargetCpaBiddingScheme]/targetCpa/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault' => 'Google::Ads::AdWords::v201406::ApiException',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/status' => 'Google::Ads::AdWords::v201406::SharedBiddingStrategy::BiddingStrategyStatus',
               'mutate/operations/operand/biddingScheme[TargetSpendBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201406::Money',
               'queryResponse/rval/entries/biddingScheme[TargetRoasBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201406::Money',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/reason' => 'Google::Ads::AdWords::v201406::SizeLimitError::Reason',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/biddingScheme[TargetSpendBiddingScheme]' => 'Google::Ads::AdWords::v201406::TargetSpendBiddingScheme',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/reason' => 'Google::Ads::AdWords::v201406::NewEntityCreationError::Reason',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/ListReturnValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenLowQualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenLowQualityScore' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/biddingScheme[TargetRoasBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/biddingScheme[TargetCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/biddingScheme[PageOnePromotedBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidCeiling' => 'Google::Ads::AdWords::v201406::Money',
               'mutate/operations/operand/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidFloor/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidFloor/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/biddingScheme[BudgetOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DateError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]' => 'Google::Ads::AdWords::v201406::DistinctError',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/reason' => 'Google::Ads::AdWords::v201406::RequestError::Reason',
               'queryResponse/rval/entries/biddingScheme[EnhancedCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/biddingScheme[TargetRoasBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201406::Money',
               'Fault/detail' => 'Google::Ads::AdWords::FaultDetail',
               'mutateResponse/rval/value/biddingScheme[ManualCpcBiddingScheme]' => 'Google::Ads::AdWords::v201406::ManualCpcBiddingScheme',
               'mutate/operations/operand/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/biddingScheme[TargetCpaBiddingScheme]/targetCpa' => 'Google::Ads::AdWords::v201406::Money',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/biddingScheme[TargetSpendBiddingScheme]/spendTarget' => 'Google::Ads::AdWords::v201406::Money',
               'queryResponse/rval/entries/biddingScheme[TargetRoasBiddingScheme]/targetRoas' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries/biddingScheme[PercentCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/biddingScheme[TargetCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/biddingScheme[ManualCpcBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/biddingScheme[ConversionOptimizerBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/biddingScheme[ManualCpmBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/biddingScheme[TargetRoasBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenBudgetConstained' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[IdError]' => 'Google::Ads::AdWords::v201406::IdError',
               'queryResponse/rval/entries/biddingScheme[ManualCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/biddingScheme[ManualCpcBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault' => 'Google::Ads::AdWords::v201406::ApiException',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/dateRange' => 'Google::Ads::AdWords::v201406::DateRange',
               'mutateResponse/rval' => 'Google::Ads::AdWords::v201406::BiddingStrategyReturnValue',
               'mutate/operations/operand/biddingScheme[PercentCpaBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/biddingScheme[TargetSpendBiddingScheme]/spendTarget/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'query/query' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/reason' => 'Google::Ads::AdWords::v201406::OperationAccessDenied::Reason',
               'mutate/operations/operand/biddingScheme[TargetRoasBiddingScheme]' => 'Google::Ads::AdWords::v201406::TargetRoasBiddingScheme',
               'getResponse/rval/totalNumEntries' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand/biddingScheme[BudgetOptimizerBiddingScheme]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/reason' => 'Google::Ads::AdWords::v201406::RangeError::Reason',
               'mutate/operations/operand/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]' => 'Google::Ads::AdWords::v201406::ReadOnlyError',
               'mutateResponse/rval/value/biddingScheme[TargetRoasBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RequestError]' => 'Google::Ads::AdWords::v201406::RequestError',
               'queryResponse/rval/entries/biddingScheme[PercentCpaBiddingScheme]' => 'Google::Ads::AdWords::v201406::PercentCpaBiddingScheme',
               'mutateResponse/rval/value/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201406::Money',
               'mutateResponse/rval/value' => 'Google::Ads::AdWords::v201406::SharedBiddingStrategy',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]' => 'Google::Ads::AdWords::v201406::RequiredError',
               'getResponse/rval/entries/biddingScheme[BudgetOptimizerBiddingScheme]/bidCeiling' => 'Google::Ads::AdWords::v201406::Money',
               'mutate/operations/operand/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]' => 'Google::Ads::AdWords::v201406::RejectedError',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]' => 'Google::Ads::AdWords::v201406::AuthenticationError',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]' => 'Google::Ads::AdWords::v201406::NotEmptyError',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/biddingScheme[BudgetOptimizerBiddingScheme]' => 'Google::Ads::AdWords::v201406::BudgetOptimizerBiddingScheme',
               'mutate/operations/operand/biddingScheme[TargetSpendBiddingScheme]/spendTarget' => 'Google::Ads::AdWords::v201406::Money',
               'getResponse/rval/entries/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/biddingScheme[PageOnePromotedBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/biddingScheme[ManualCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidFloor/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/biddingScheme[TargetCpaBiddingScheme]/targetCpa' => 'Google::Ads::AdWords::v201406::Money',
               'mutate/operations/operand/biddingScheme[ManualCpcBiddingScheme]' => 'Google::Ads::AdWords::v201406::ManualCpcBiddingScheme',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/biddingScheme/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/biddingScheme[ManualCpmBiddingScheme]' => 'Google::Ads::AdWords::v201406::ManualCpmBiddingScheme',
               'mutate/operations/operand/biddingScheme[TargetCpaBiddingScheme]' => 'Google::Ads::AdWords::v201406::TargetCpaBiddingScheme',
               'getResponse/rval/entries/biddingScheme[TargetRoasBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/biddingScheme[TargetCpaBiddingScheme]/targetCpa/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/biddingScheme[TargetRoasBiddingScheme]/bidFloor/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/biddingScheme[PageOnePromotedBiddingScheme]' => 'Google::Ads::AdWords::v201406::PageOnePromotedBiddingScheme',
               'mutate/operations/operand/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidCeiling' => 'Google::Ads::AdWords::v201406::Money',
               'mutateResponse/rval/value/biddingScheme[PageOnePromotedBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand' => 'Google::Ads::AdWords::v201406::SharedBiddingStrategy',
               'getResponse/rval/entries/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/biddingScheme[ManualCpcBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/biddingScheme[TargetSpendBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/biddingScheme[TargetRoasBiddingScheme]/BiddingScheme.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/biddingScheme[TargetCpaBiddingScheme]/maxCpcBidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/rateName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/biddingScheme[TargetSpendBiddingScheme]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/biddingScheme' => 'Google::Ads::AdWords::v201406::BiddingScheme',
               'get/selector' => 'Google::Ads::AdWords::v201406::Selector',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]' => 'Google::Ads::AdWords::v201406::SelectorError',
               'mutate/operations/operand/biddingScheme[PageOnePromotedBiddingScheme]/raiseBidWhenBudgetConstained' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations' => 'Google::Ads::AdWords::v201406::BiddingStrategyOperation',
               'getResponse/rval/Page.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string'
             };
;

sub get_class {
  my $name = join '/', @{ $_[1] };
  return $typemap_1->{ $name };
}

sub get_typemap {
    return $typemap_1;
}

1;

__END__

__END__

=pod

=head1 NAME

Google::Ads::AdWords::v201406::TypeMaps::BiddingStrategyService - typemap for BiddingStrategyService

=head1 DESCRIPTION

Typemap created by SOAP::WSDL for map-based SOAP message parsers.

=cut

